@@ -4,26 +4,27 @@ from geograpy.labels import Labels
 
 class Extractor(object):
     '''
-    extract geo context for text or from url
+    Extract geo context for text or from url
     '''
-    def __init__(self, text=None, url=None):
+    def __init__(self, text=None, url=None, debug=False):
         '''
-        constructor
+        Constructor
         Args:
+
             text(string): the text to analyze
             url(string): the url to read the text to analyze from
-            
+            debug(boolean): if True show debug information
         '''
         if not text and not url:
             raise Exception('text or url is required')
-
+        self.debug=debug
         self.text = text
         self.url = url
         self.places = []
 
     def set_text(self):
         '''
-        setter for text
+        Setter for text
         '''
         if not self.text and self.url:
             a = Article(self.url)
@@ -33,21 +34,24 @@ class Extractor(object):
             
     def find_geoEntities(self):
         '''
-        find geographic entities
+        Find geographic entities
         
         Returns:
-            list: of places
+            list: 
+                List of places
         '''
         self.find_entities(Labels.geo)
         return self.places
 
     def find_entities(self,labels=Labels.default):
         '''
-        find entities with the given labels set self.places and returns it
+        Find entities with the given labels set self.places and returns it
         Args:
-            labels(Labels): the labels to filter
+            labels: 
+                Labels: The labels to filter
         Returns:
-            list: of places
+            list: 
+                List of places
         '''
         self.set_text()
 
@@ -57,5 +61,8 @@ class Extractor(object):
         for ne in nes:
             if type(ne) is nltk.tree.Tree:
                 if (ne.label() in labels):
-                    self.places.append(u' '.join([i[0] for i in ne.leaves()]))
+                    leaves=ne.leaves()
+                    if self.debug:
+                        print(leaves)
+                    self.places.append(u' '.join([i[0] for i in leaves]))
         return self.places
\ No newline at end of file
