@@ -186,7 +186,10 @@ class PlaceContext(object):
 
             try:
                 country = pycountry.countries.get(alpha_2=row[3])
-                country_name = country.name
+                if country is not None:
+                    country_name = country.name
+                else:
+                    country_name = row[4]
             except KeyError as e:
                 country_name = row[4]
 
@@ -201,7 +204,7 @@ class PlaceContext(object):
                 self.country_mentions.append((country_name, 1))
 
             if country_name not in self.country_cities:
-                self.country_cities[country.name] = []
+                self.country_cities[country_name] = []
 
             if city_name not in self.country_cities[country_name]:
                 self.country_cities[country_name].append(city_name)
